# These must be the same as in the PostgreSQL RPM:
%{!?%packagename:%global packagename rh-postgresql95-postgresql}
%{!?shortname:%global shortname pgsql}
%{!?%majorversion:%global majorversion 9.5}
%{!?%shortmajorversion:%global shortmajorversion 95}

%{!?pgbaseinstdir:%global pgbaseinstdir /opt/rh/rh-postgresql95/root/usr/}

# The version of the underlying PostgreSQL release we require, coresponding to
# Version: in the Pg RPM, and optionally the Release too.
%{!?required_pg:%global required_pg 9.5}

# If you're building a git snapshot, you must set the githash macro so that
# the spec file will locate the correct tarball. If you're building a tagged
# final release you must instead set the gittag macro.
#
#% define githash 1deadbe
# -or-
#% define gittag something
#

# If you --define a githash or set it in a macro, adds it to the Release field:
%{?githash:%global releasegitsuffix _git%{githash}}

Name:		%{packagename}-pglogical
Version:	2.0.1
Release:	1%{?releasegitsuffix}%{?releasetag}%{?dist}
Summary:	pglogical - trigger-free streaming logical replication

Group:		Applications/Databases
License:	PostgreSQL
URL:		http://2ndquadrant.com/pglogical
Source0:	pglogical-%{version}.tar.bz2
Source1:	pglogical-%{version}.tar.bz2.md5

BuildRequires:		%{packagename}-devel%{?_isa} >= %{required_pg}
BuildRequires:		%{packagename}-static%{?_isa} >= %{required_pg}
Requires:		%{packagename}%{?_isa} >= %{required_pg}
Requires:		%{packagename}-server%{?_isa} >= %{required_pg}

# These should match those in the PostgreSQL spec, as they're headers
# PostgreSQL exposes via includes in its own public headers, and/or or that
# pg_config will emit linker options to link to.
#
# These should actually be Requires: dependencies of postgresql94-devel, but
# they aren't; see http://www.postgresql.org/message-id/547C0032.7040309@2ndquadrant.com
#
BuildRequires:  openssl-devel
BuildRequires:  gettext >= 0.10.35
BuildRequires:  libxml2-devel libxslt-devel
BuildRequires:  pam-devel
BuildRequires:  readline-devel
BuildRequires:  zlib-devel >= 1.0.4

# pglogical-output now merged into this package
Provides: %{packagename}-pglogical-output = %{version}
Obsoletes: %{packagename}-pglogical-output < %{version}

%description
Ths package installs the pglogical plugin that provides logical streaming
replication for PostgreSQL using a publish/subscribe model.  It can be used for
upgrades between major versions, full database replication, selective
replication, & gathering/merging data from multiple upstream servers.

pglogical is developed, maintained, and supported by 2ndQuadrant
(http://2ndquadrant.com).

This package is built for PostgreSQL %{packagename}%{shortmajorversion}
from http://yum.postgresql.org/

%prep
# Enforce that you must set gittag or githash
%if "%{?gittag}" != "" && "%{?githash}" != ""
  %{error:Both %%gittag and %%githash set, bad spec file configuration. See README.md}
%else
  %if "%{?gittag}" == "" && "%{?githash}" == ""
    %{error:No %%gittag or %%githash set, bad spec file configuration. See README.md}
  %endif
%endif

%setup -q -n pglogical-%{version}%{?releasegitsuffix}

%build
%{?scl:scl enable rh-postgresql95 - << \EOF}
export PATH=%{pgbaseinstdir}/bin:$PATH
make USE_PGXS=1 -s %{?_smp_mflags}
%{?scl:EOF}

%install
%{?scl:scl enable rh-postgresql95 - << \EOF}
export PATH=%{pgbaseinstdir}/bin:$PATH
make USE_PGXS=1 DESTDIR=%{buildroot} install
%{?scl:EOF}

mkdir -p %{buildroot}/usr/share/doc/%{packagename}%{shortmajorversion}-pglogical
cp README.md %{buildroot}/usr/share/doc/%{packagename}%{shortmajorversion}-pglogical/

%files
%{pgbaseinstdir}/lib64/pgsql/pglogical.so
%{pgbaseinstdir}/lib64/pgsql/pglogical_output.so
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.*.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--2.*.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical.control
%{pgbaseinstdir}/share/pgsql/extension/pglogical_origin--1.0.0.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical_origin.control
%if "%{shortmajorversion}" == "94"
%{pgbaseinstdir}/bin/pglogical_dump
%endif
%{pgbaseinstdir}/bin/pglogical_create_subscriber
/usr/share/doc/%{packagename}%{shortmajorversion}-pglogical/README.md

%changelog
* Thu Jun 01 2017 Petr Jelinek <petr.jelinek@2ndquadrant.com> 2.0.1-1
- Bugfix release

* Tue May 02 2017 Marco Nenciarini <marco.nenciarini@2ndquadrant.it> 2.0.0-1
- New version
- pglogical-output has merged into the main extension

* Mon Dec 26 2016 Petr Jelinek <petr.jelinek@2ndquadrant.com> 1.2.2-1_2ndQuadrant
- Bugfix release

* Mon Oct 10 2016 Craig Ringer <craig.ringer@2ndquadrant.com> 1.2.1-1_2ndQuadrant
- Fix compatibility with 9.4 as downstream (GH #45)
- Better error for 'snapshot is too large'
- Ignore missing origin when cascading
- Don't package hooks header anymore

* Mon Sep 19 2016 Craig Ringer <craig.ringer@2ndquadrant.com> 1.2.0-1_2ndQuadrant
- The 1.2 update integrates the pglogical_output extension
- First release targeting PostgreSQL 9.6rc1

* Thu Jun 09 2016 Craig Ringer <craig.ringer@2ndquadrant.com> 1.1.2-1_2ndQuadrant
- Bug fixes for 1.1.0 stable series

* Tue Dec 22 2015 Craig Ringer <craig@2ndquadrant.com> 1.0.0-1_2ndQuadrant
- First cut pglogical package
